Documentation
¶
Overview ¶
Package resourcegraph implements the Azure ARM Resourcegraph service API version .
Azure Resource Graph API Reference
Index ¶
- Constants
- func UserAgent() string
- func Version() string
- type BaseClient
- func (client BaseClient) ResourceChangeDetails(ctx context.Context, parameters ResourceChangeDetailsRequestParameters) (result ListResourceChangeData, err error)
- func (client BaseClient) ResourceChangeDetailsPreparer(ctx context.Context, parameters ResourceChangeDetailsRequestParameters) (*http.Request, error)
- func (client BaseClient) ResourceChangeDetailsResponder(resp *http.Response) (result ListResourceChangeData, err error)
- func (client BaseClient) ResourceChangeDetailsSender(req *http.Request) (*http.Response, error)
- func (client BaseClient) ResourceChanges(ctx context.Context, parameters ResourceChangesRequestParameters) (result ResourceChangeList, err error)
- func (client BaseClient) ResourceChangesPreparer(ctx context.Context, parameters ResourceChangesRequestParameters) (*http.Request, error)
- func (client BaseClient) ResourceChangesResponder(resp *http.Response) (result ResourceChangeList, err error)
- func (client BaseClient) ResourceChangesSender(req *http.Request) (*http.Response, error)
- func (client BaseClient) Resources(ctx context.Context, query QueryRequest) (result QueryResponse, err error)
- func (client BaseClient) ResourcesHistory(ctx context.Context, request ResourcesHistoryRequest) (result SetObject, err error)
- func (client BaseClient) ResourcesHistoryPreparer(ctx context.Context, request ResourcesHistoryRequest) (*http.Request, error)
- func (client BaseClient) ResourcesHistoryResponder(resp *http.Response) (result SetObject, err error)
- func (client BaseClient) ResourcesHistorySender(req *http.Request) (*http.Response, error)
- func (client BaseClient) ResourcesPreparer(ctx context.Context, query QueryRequest) (*http.Request, error)
- func (client BaseClient) ResourcesResponder(resp *http.Response) (result QueryResponse, err error)
- func (client BaseClient) ResourcesSender(req *http.Request) (*http.Response, error)
- type BasicFacet
- type ChangeCategory
- type ChangeType
- type Column
- type ColumnDataType
- type DateTimeInterval
- type Error
- type ErrorDetails
- type ErrorResponse
- type Facet
- type FacetError
- type FacetRequest
- type FacetRequestOptions
- type FacetResult
- type FacetSortOrder
- type ListResourceChangeData
- type Operation
- type OperationDisplay
- type OperationListResult
- type OperationsClient
- func (client OperationsClient) List(ctx context.Context) (result OperationListResult, err error)
- func (client OperationsClient) ListPreparer(ctx context.Context) (*http.Request, error)
- func (client OperationsClient) ListResponder(resp *http.Response) (result OperationListResult, err error)
- func (client OperationsClient) ListSender(req *http.Request) (*http.Response, error)
- type PropertyChangeType
- type QueryRequest
- type QueryRequestOptions
- type QueryResponse
- type ResourceChangeData
- type ResourceChangeDataAfterSnapshot
- type ResourceChangeDataBeforeSnapshot
- type ResourceChangeDetailsRequestParameters
- type ResourceChangeList
- type ResourceChangesRequestParameters
- type ResourceChangesRequestParametersInterval
- type ResourcePropertyChange
- type ResourceSnapshotData
- type ResourcesHistoryRequest
- type ResourcesHistoryRequestOptions
- type ResultFormat
- type ResultFormat1
- type ResultTruncated
- type ResultType
- type SetObject
- type Table
Constants ¶
const (
// DefaultBaseURI is the default URI used for the service Resourcegraph
DefaultBaseURI = "https://management.azure.com"
)
Variables ¶
This section is empty.
Functions ¶
func UserAgent ¶
func UserAgent() string
UserAgent returns the UserAgent string to use when sending http.Requests.
func Version ¶
func Version() string
Version returns the semantic version (see http://semver.org) of the client.
Types ¶
type BaseClient ¶
BaseClient is the base client for Resourcegraph.
func NewWithBaseURI ¶
func NewWithBaseURI(baseURI string) BaseClient
NewWithBaseURI creates an instance of the BaseClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (BaseClient) ResourceChangeDetails ¶
func (client BaseClient) ResourceChangeDetails(ctx context.Context, parameters ResourceChangeDetailsRequestParameters) (result ListResourceChangeData, err error)
ResourceChangeDetails get resource change details. Parameters: parameters - the parameters for this request for resource change details.
func (BaseClient) ResourceChangeDetailsPreparer ¶
func (client BaseClient) ResourceChangeDetailsPreparer(ctx context.Context, parameters ResourceChangeDetailsRequestParameters) (*http.Request, error)
ResourceChangeDetailsPreparer prepares the ResourceChangeDetails request.
func (BaseClient) ResourceChangeDetailsResponder ¶
func (client BaseClient) ResourceChangeDetailsResponder(resp *http.Response) (result ListResourceChangeData, err error)
ResourceChangeDetailsResponder handles the response to the ResourceChangeDetails request. The method always closes the http.Response Body.
func (BaseClient) ResourceChangeDetailsSender ¶
ResourceChangeDetailsSender sends the ResourceChangeDetails request. The method will close the http.Response Body if it receives an error.
func (BaseClient) ResourceChanges ¶
func (client BaseClient) ResourceChanges(ctx context.Context, parameters ResourceChangesRequestParameters) (result ResourceChangeList, err error)
ResourceChanges list changes to a resource for a given time interval. Parameters: parameters - the parameters for this request for changes.
func (BaseClient) ResourceChangesPreparer ¶
func (client BaseClient) ResourceChangesPreparer(ctx context.Context, parameters ResourceChangesRequestParameters) (*http.Request, error)
ResourceChangesPreparer prepares the ResourceChanges request.
func (BaseClient) ResourceChangesResponder ¶
func (client BaseClient) ResourceChangesResponder(resp *http.Response) (result ResourceChangeList, err error)
ResourceChangesResponder handles the response to the ResourceChanges request. The method always closes the http.Response Body.
func (BaseClient) ResourceChangesSender ¶
ResourceChangesSender sends the ResourceChanges request. The method will close the http.Response Body if it receives an error.
func (BaseClient) Resources ¶
func (client BaseClient) Resources(ctx context.Context, query QueryRequest) (result QueryResponse, err error)
Resources queries the resources managed by Azure Resource Manager for scopes specified in the request. Parameters: query - request specifying query and its options.
func (BaseClient) ResourcesHistory ¶
func (client BaseClient) ResourcesHistory(ctx context.Context, request ResourcesHistoryRequest) (result SetObject, err error)
ResourcesHistory list all snapshots of a resource for a given time interval.
func (BaseClient) ResourcesHistoryPreparer ¶
func (client BaseClient) ResourcesHistoryPreparer(ctx context.Context, request ResourcesHistoryRequest) (*http.Request, error)
ResourcesHistoryPreparer prepares the ResourcesHistory request.
func (BaseClient) ResourcesHistoryResponder ¶
func (client BaseClient) ResourcesHistoryResponder(resp *http.Response) (result SetObject, err error)
ResourcesHistoryResponder handles the response to the ResourcesHistory request. The method always closes the http.Response Body.
func (BaseClient) ResourcesHistorySender ¶
ResourcesHistorySender sends the ResourcesHistory request. The method will close the http.Response Body if it receives an error.
func (BaseClient) ResourcesPreparer ¶
func (client BaseClient) ResourcesPreparer(ctx context.Context, query QueryRequest) (*http.Request, error)
ResourcesPreparer prepares the Resources request.
func (BaseClient) ResourcesResponder ¶
func (client BaseClient) ResourcesResponder(resp *http.Response) (result QueryResponse, err error)
ResourcesResponder handles the response to the Resources request. The method always closes the http.Response Body.
func (BaseClient) ResourcesSender ¶
ResourcesSender sends the Resources request. The method will close the http.Response Body if it receives an error.
type BasicFacet ¶
type BasicFacet interface {
AsFacetResult() (*FacetResult, bool)
AsFacetError() (*FacetError, bool)
AsFacet() (*Facet, bool)
}
BasicFacet a facet containing additional statistics on the response of a query. Can be either FacetResult or FacetError.
type ChangeCategory ¶
type ChangeCategory string
ChangeCategory enumerates the values for change category.
const ( // ChangeCategorySystem ... ChangeCategorySystem ChangeCategory = "System" // ChangeCategoryUser ... ChangeCategoryUser ChangeCategory = "User" )
func PossibleChangeCategoryValues ¶
func PossibleChangeCategoryValues() []ChangeCategory
PossibleChangeCategoryValues returns an array of possible values for the ChangeCategory const type.
type ChangeType ¶
type ChangeType string
ChangeType enumerates the values for change type.
const ( // ChangeTypeCreate ... ChangeTypeCreate ChangeType = "Create" // ChangeTypeDelete ... ChangeTypeDelete ChangeType = "Delete" // ChangeTypeUpdate ... ChangeTypeUpdate ChangeType = "Update" )
func PossibleChangeTypeValues ¶
func PossibleChangeTypeValues() []ChangeType
PossibleChangeTypeValues returns an array of possible values for the ChangeType const type.
type Column ¶
type Column struct {
// Name - Column name.
Name *string `json:"name,omitempty"`
// Type - Column data type. Possible values include: 'ColumnDataTypeString', 'ColumnDataTypeInteger', 'ColumnDataTypeNumber', 'ColumnDataTypeBoolean', 'ColumnDataTypeObject'
Type ColumnDataType `json:"type,omitempty"`
}
Column query result column descriptor.
type ColumnDataType ¶
type ColumnDataType string
ColumnDataType enumerates the values for column data type.
const ( // ColumnDataTypeBoolean ... ColumnDataTypeBoolean ColumnDataType = "boolean" // ColumnDataTypeInteger ... ColumnDataTypeInteger ColumnDataType = "integer" // ColumnDataTypeNumber ... ColumnDataTypeNumber ColumnDataType = "number" // ColumnDataTypeObject ... ColumnDataTypeObject ColumnDataType = "object" // ColumnDataTypeString ... ColumnDataTypeString ColumnDataType = "string" )
func PossibleColumnDataTypeValues ¶
func PossibleColumnDataTypeValues() []ColumnDataType
PossibleColumnDataTypeValues returns an array of possible values for the ColumnDataType const type.
type DateTimeInterval ¶
type DateTimeInterval struct {
// Start - A datetime indicating the inclusive/closed start of the time interval, i.e. `[`**`start`**`, end)`. Specifying a `start` that occurs chronologically after `end` will result in an error.
Start *date.Time `json:"start,omitempty"`
// End - A datetime indicating the exclusive/open end of the time interval, i.e. `[start, `**`end`**`)`. Specifying an `end` that occurs chronologically before `start` will result in an error.
End *date.Time `json:"end,omitempty"`
}
DateTimeInterval an interval in time specifying the date and time for the inclusive start and exclusive end, i.e. `[start, end)`.
type Error ¶
type Error struct {
// Code - Error code identifying the specific error.
Code *string `json:"code,omitempty"`
// Message - A human readable error message.
Message *string `json:"message,omitempty"`
// Details - Error details
Details *[]ErrorDetails `json:"details,omitempty"`
}
Error error details.
type ErrorDetails ¶
type ErrorDetails struct {
// AdditionalProperties - Unmatched properties from the message are deserialized this collection
AdditionalProperties map[string]interface{} `json:""`
// Code - Error code identifying the specific error.
Code *string `json:"code,omitempty"`
// Message - A human readable error message.
Message *string `json:"message,omitempty"`
}
ErrorDetails ...
func (ErrorDetails) MarshalJSON ¶
func (ed ErrorDetails) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for ErrorDetails.
func (*ErrorDetails) UnmarshalJSON ¶
func (ed *ErrorDetails) UnmarshalJSON(body []byte) error
UnmarshalJSON is the custom unmarshaler for ErrorDetails struct.
type ErrorResponse ¶
type ErrorResponse struct {
// Error - Error information.
Error *Error `json:"error,omitempty"`
}
ErrorResponse an error response from the API.
type Facet ¶
type Facet struct {
// Expression - Facet expression, same as in the corresponding facet request.
Expression *string `json:"expression,omitempty"`
// ResultType - Possible values include: 'ResultTypeResultTypeFacet', 'ResultTypeResultTypeFacetResult', 'ResultTypeResultTypeFacetError'
ResultType ResultType `json:"resultType,omitempty"`
}
Facet a facet containing additional statistics on the response of a query. Can be either FacetResult or FacetError.
func (Facet) AsBasicFacet ¶
func (f Facet) AsBasicFacet() (BasicFacet, bool)
AsBasicFacet is the BasicFacet implementation for Facet.
func (Facet) AsFacetError ¶
func (f Facet) AsFacetError() (*FacetError, bool)
AsFacetError is the BasicFacet implementation for Facet.
func (Facet) AsFacetResult ¶
func (f Facet) AsFacetResult() (*FacetResult, bool)
AsFacetResult is the BasicFacet implementation for Facet.
func (Facet) MarshalJSON ¶
MarshalJSON is the custom marshaler for Facet.
type FacetError ¶
type FacetError struct {
// Errors - An array containing detected facet errors with details.
Errors *[]ErrorDetails `json:"errors,omitempty"`
// Expression - Facet expression, same as in the corresponding facet request.
Expression *string `json:"expression,omitempty"`
// ResultType - Possible values include: 'ResultTypeResultTypeFacet', 'ResultTypeResultTypeFacetResult', 'ResultTypeResultTypeFacetError'
ResultType ResultType `json:"resultType,omitempty"`
}
FacetError a facet whose execution resulted in an error.
func (FacetError) AsBasicFacet ¶
func (fe FacetError) AsBasicFacet() (BasicFacet, bool)
AsBasicFacet is the BasicFacet implementation for FacetError.
func (FacetError) AsFacet ¶
func (fe FacetError) AsFacet() (*Facet, bool)
AsFacet is the BasicFacet implementation for FacetError.
func (FacetError) AsFacetError ¶
func (fe FacetError) AsFacetError() (*FacetError, bool)
AsFacetError is the BasicFacet implementation for FacetError.
func (FacetError) AsFacetResult ¶
func (fe FacetError) AsFacetResult() (*FacetResult, bool)
AsFacetResult is the BasicFacet implementation for FacetError.
func (FacetError) MarshalJSON ¶
func (fe FacetError) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for FacetError.
type FacetRequest ¶
type FacetRequest struct {
// Expression - The column or list of columns to summarize by
Expression *string `json:"expression,omitempty"`
// Options - The options for facet evaluation
Options *FacetRequestOptions `json:"options,omitempty"`
}
FacetRequest a request to compute additional statistics (facets) over the query results.
type FacetRequestOptions ¶
type FacetRequestOptions struct {
// SortBy - The column name or query expression to sort on. Defaults to count if not present.
SortBy *string `json:"sortBy,omitempty"`
// SortOrder - The sorting order by the selected column (count by default). Possible values include: 'FacetSortOrderAsc', 'FacetSortOrderDesc'
SortOrder FacetSortOrder `json:"sortOrder,omitempty"`
// Filter - Specifies the filter condition for the 'where' clause which will be run on main query's result, just before the actual faceting.
Filter *string `json:"filter,omitempty"`
// Top - The maximum number of facet rows that should be returned.
Top *int32 `json:"$top,omitempty"`
}
FacetRequestOptions the options for facet evaluation
type FacetResult ¶
type FacetResult struct {
// TotalRecords - Number of total records in the facet results.
TotalRecords *int64 `json:"totalRecords,omitempty"`
// Count - Number of records returned in the facet response.
Count *int32 `json:"count,omitempty"`
// Data - A JObject array or Table containing the desired facets. Only present if the facet is valid.
Data interface{} `json:"data,omitempty"`
// Expression - Facet expression, same as in the corresponding facet request.
Expression *string `json:"expression,omitempty"`
// ResultType - Possible values include: 'ResultTypeResultTypeFacet', 'ResultTypeResultTypeFacetResult', 'ResultTypeResultTypeFacetError'
ResultType ResultType `json:"resultType,omitempty"`
}
FacetResult successfully executed facet containing additional statistics on the response of a query.
func (FacetResult) AsBasicFacet ¶
func (fr FacetResult) AsBasicFacet() (BasicFacet, bool)
AsBasicFacet is the BasicFacet implementation for FacetResult.
func (FacetResult) AsFacet ¶
func (fr FacetResult) AsFacet() (*Facet, bool)
AsFacet is the BasicFacet implementation for FacetResult.
func (FacetResult) AsFacetError ¶
func (fr FacetResult) AsFacetError() (*FacetError, bool)
AsFacetError is the BasicFacet implementation for FacetResult.
func (FacetResult) AsFacetResult ¶
func (fr FacetResult) AsFacetResult() (*FacetResult, bool)
AsFacetResult is the BasicFacet implementation for FacetResult.
func (FacetResult) MarshalJSON ¶
func (fr FacetResult) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for FacetResult.
type FacetSortOrder ¶
type FacetSortOrder string
FacetSortOrder enumerates the values for facet sort order.
const ( // FacetSortOrderAsc ... FacetSortOrderAsc FacetSortOrder = "asc" // FacetSortOrderDesc ... FacetSortOrderDesc FacetSortOrder = "desc" )
func PossibleFacetSortOrderValues ¶
func PossibleFacetSortOrderValues() []FacetSortOrder
PossibleFacetSortOrderValues returns an array of possible values for the FacetSortOrder const type.
type ListResourceChangeData ¶
type ListResourceChangeData struct {
autorest.Response `json:"-"`
Value *[]ResourceChangeData `json:"value,omitempty"`
}
ListResourceChangeData ...
type Operation ¶
type Operation struct {
// Name - Operation name: {provider}/{resource}/{operation}
Name *string `json:"name,omitempty"`
// Display - Display metadata associated with the operation.
Display *OperationDisplay `json:"display,omitempty"`
// Origin - The origin of operations.
Origin *string `json:"origin,omitempty"`
}
Operation resource Graph REST API operation definition.
type OperationDisplay ¶
type OperationDisplay struct {
// Provider - Service provider: Microsoft Resource Graph.
Provider *string `json:"provider,omitempty"`
// Resource - Resource on which the operation is performed etc.
Resource *string `json:"resource,omitempty"`
// Operation - Type of operation: get, read, delete, etc.
Operation *string `json:"operation,omitempty"`
// Description - Description for the operation.
Description *string `json:"description,omitempty"`
}
OperationDisplay display metadata associated with the operation.
type OperationListResult ¶
type OperationListResult struct {
autorest.Response `json:"-"`
// Value - List of Resource Graph operations supported by the Resource Graph resource provider.
Value *[]Operation `json:"value,omitempty"`
}
OperationListResult result of the request to list Resource Graph operations. It contains a list of operations and a URL link to get the next set of results.
type OperationsClient ¶
type OperationsClient struct {
BaseClient
}
OperationsClient is the azure Resource Graph API Reference
func NewOperationsClient ¶
func NewOperationsClient() OperationsClient
NewOperationsClient creates an instance of the OperationsClient client.
func NewOperationsClientWithBaseURI ¶
func NewOperationsClientWithBaseURI(baseURI string) OperationsClient
NewOperationsClientWithBaseURI creates an instance of the OperationsClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (OperationsClient) List ¶
func (client OperationsClient) List(ctx context.Context) (result OperationListResult, err error)
List lists all of the available REST API operations.
func (OperationsClient) ListPreparer ¶
ListPreparer prepares the List request.
func (OperationsClient) ListResponder ¶
func (client OperationsClient) ListResponder(resp *http.Response) (result OperationListResult, err error)
ListResponder handles the response to the List request. The method always closes the http.Response Body.
func (OperationsClient) ListSender ¶
ListSender sends the List request. The method will close the http.Response Body if it receives an error.
type PropertyChangeType ¶
type PropertyChangeType string
PropertyChangeType enumerates the values for property change type.
const ( // PropertyChangeTypeInsert ... PropertyChangeTypeInsert PropertyChangeType = "Insert" // PropertyChangeTypeRemove ... PropertyChangeTypeRemove PropertyChangeType = "Remove" // PropertyChangeTypeUpdate ... PropertyChangeTypeUpdate PropertyChangeType = "Update" )
func PossiblePropertyChangeTypeValues ¶
func PossiblePropertyChangeTypeValues() []PropertyChangeType
PossiblePropertyChangeTypeValues returns an array of possible values for the PropertyChangeType const type.
type QueryRequest ¶
type QueryRequest struct {
// Subscriptions - Azure subscriptions against which to execute the query.
Subscriptions *[]string `json:"subscriptions,omitempty"`
// ManagementGroups - Azure management groups against which to execute the query. Example: [ 'mg1', 'mg2' ]
ManagementGroups *[]string `json:"managementGroups,omitempty"`
// Query - The resources query.
Query *string `json:"query,omitempty"`
// Options - The query evaluation options
Options *QueryRequestOptions `json:"options,omitempty"`
// Facets - An array of facet requests to be computed against the query result.
Facets *[]FacetRequest `json:"facets,omitempty"`
}
QueryRequest describes a query to be executed.
type QueryRequestOptions ¶
type QueryRequestOptions struct {
// SkipToken - Continuation token for pagination, capturing the next page size and offset, as well as the context of the query.
SkipToken *string `json:"$skipToken,omitempty"`
// Top - The maximum number of rows that the query should return. Overrides the page size when “`$skipToken“` property is present.
Top *int32 `json:"$top,omitempty"`
// Skip - The number of rows to skip from the beginning of the results. Overrides the next page offset when “`$skipToken“` property is present.
Skip *int32 `json:"$skip,omitempty"`
// ResultFormat - Defines in which format query result returned. Possible values include: 'ResultFormatTable', 'ResultFormatObjectArray'
ResultFormat ResultFormat `json:"resultFormat,omitempty"`
// AllowPartialScopes - Only applicable for tenant and management group level queries to decide whether to allow partial scopes for result in case the number of subscriptions exceed allowed limits.
AllowPartialScopes *bool `json:"allowPartialScopes,omitempty"`
}
QueryRequestOptions the options for query evaluation
type QueryResponse ¶
type QueryResponse struct {
autorest.Response `json:"-"`
// TotalRecords - Number of total records matching the query.
TotalRecords *int64 `json:"totalRecords,omitempty"`
// Count - Number of records returned in the current response. In the case of paging, this is the number of records in the current page.
Count *int64 `json:"count,omitempty"`
// ResultTruncated - Indicates whether the query results are truncated. Possible values include: 'ResultTruncatedTrue', 'ResultTruncatedFalse'
ResultTruncated ResultTruncated `json:"resultTruncated,omitempty"`
// SkipToken - When present, the value can be passed to a subsequent query call (together with the same query and scopes used in the current request) to retrieve the next page of data.
SkipToken *string `json:"$skipToken,omitempty"`
// Data - Query output in JObject array or Table format.
Data interface{} `json:"data,omitempty"`
// Facets - Query facets.
Facets *[]BasicFacet `json:"facets,omitempty"`
}
QueryResponse query result.
func (*QueryResponse) UnmarshalJSON ¶
func (qr *QueryResponse) UnmarshalJSON(body []byte) error
UnmarshalJSON is the custom unmarshaler for QueryResponse struct.
type ResourceChangeData ¶
type ResourceChangeData struct {
// ResourceID - The resource for a change.
ResourceID *string `json:"resourceId,omitempty"`
// ChangeID - The change ID. Valid and unique within the specified resource only.
ChangeID *string `json:"changeId,omitempty"`
// BeforeSnapshot - The snapshot before the change.
BeforeSnapshot *ResourceChangeDataBeforeSnapshot `json:"beforeSnapshot,omitempty"`
// AfterSnapshot - The snapshot after the change.
AfterSnapshot *ResourceChangeDataAfterSnapshot `json:"afterSnapshot,omitempty"`
// ChangeType - The change type for snapshot. PropertyChanges will be provided in case of Update change type. Possible values include: 'ChangeTypeCreate', 'ChangeTypeUpdate', 'ChangeTypeDelete'
ChangeType ChangeType `json:"changeType,omitempty"`
// PropertyChanges - An array of resource property change
PropertyChanges *[]ResourcePropertyChange `json:"propertyChanges,omitempty"`
}
ResourceChangeData data on a specific change, represented by a pair of before and after resource snapshots.
type ResourceChangeDataAfterSnapshot ¶
type ResourceChangeDataAfterSnapshot struct {
// SnapshotID - The ID of the snapshot.
SnapshotID *string `json:"snapshotId,omitempty"`
// Timestamp - The time when the snapshot was created.
// The snapshot timestamp provides an approximation as to when a modification to a resource was detected. There can be a difference between the actual modification time and the detection time. This is due to differences in how operations that modify a resource are processed, versus how operation that record resource snapshots are processed.
Timestamp *date.Time `json:"timestamp,omitempty"`
// Content - The resource snapshot content (in resourceChangeDetails response only).
Content interface{} `json:"content,omitempty"`
}
ResourceChangeDataAfterSnapshot the snapshot after the change.
type ResourceChangeDataBeforeSnapshot ¶
type ResourceChangeDataBeforeSnapshot struct {
// SnapshotID - The ID of the snapshot.
SnapshotID *string `json:"snapshotId,omitempty"`
// Timestamp - The time when the snapshot was created.
// The snapshot timestamp provides an approximation as to when a modification to a resource was detected. There can be a difference between the actual modification time and the detection time. This is due to differences in how operations that modify a resource are processed, versus how operation that record resource snapshots are processed.
Timestamp *date.Time `json:"timestamp,omitempty"`
// Content - The resource snapshot content (in resourceChangeDetails response only).
Content interface{} `json:"content,omitempty"`
}
ResourceChangeDataBeforeSnapshot the snapshot before the change.
type ResourceChangeDetailsRequestParameters ¶
type ResourceChangeDetailsRequestParameters struct {
// ResourceIds - Specifies the list of resources for a change details request.
ResourceIds *[]string `json:"resourceIds,omitempty"`
// ChangeIds - Specifies the list of change IDs for a change details request.
ChangeIds *[]string `json:"changeIds,omitempty"`
}
ResourceChangeDetailsRequestParameters the parameters for a specific change details request.
type ResourceChangeList ¶
type ResourceChangeList struct {
autorest.Response `json:"-"`
// Changes - The pageable value returned by the operation, i.e. a list of changes to the resource.
// - The list is ordered from the most recent changes to the least recent changes.
// - This list will be empty if there were no changes during the requested interval.
// - The `Before` snapshot timestamp value of the oldest change can be outside of the specified time interval.
Changes *[]ResourceChangeData `json:"changes,omitempty"`
// SkipToken - Skip token that encodes the skip information while executing the current request
SkipToken interface{} `json:"$skipToken,omitempty"`
}
ResourceChangeList a list of changes associated with a resource over a specific time interval.
type ResourceChangesRequestParameters ¶
type ResourceChangesRequestParameters struct {
// ResourceIds - Specifies the list of resources for a changes request.
ResourceIds *[]string `json:"resourceIds,omitempty"`
// SubscriptionID - The subscription id of resources to query the changes from.
SubscriptionID *string `json:"subscriptionId,omitempty"`
// Interval - Specifies the date and time interval for a changes request.
Interval *ResourceChangesRequestParametersInterval `json:"interval,omitempty"`
// SkipToken - Acts as the continuation token for paged responses.
SkipToken *string `json:"$skipToken,omitempty"`
// Top - The maximum number of changes the client can accept in a paged response.
Top *int32 `json:"$top,omitempty"`
// Table - The table name to query resources from.
Table *string `json:"table,omitempty"`
// FetchPropertyChanges - The flag if set to true will fetch property changes
FetchPropertyChanges *bool `json:"fetchPropertyChanges,omitempty"`
// FetchSnapshots - The flag if set to true will fetch change snapshots
FetchSnapshots *bool `json:"fetchSnapshots,omitempty"`
}
ResourceChangesRequestParameters the parameters for a specific changes request.
type ResourceChangesRequestParametersInterval ¶
type ResourceChangesRequestParametersInterval struct {
// Start - A datetime indicating the inclusive/closed start of the time interval, i.e. `[`**`start`**`, end)`. Specifying a `start` that occurs chronologically after `end` will result in an error.
Start *date.Time `json:"start,omitempty"`
// End - A datetime indicating the exclusive/open end of the time interval, i.e. `[start, `**`end`**`)`. Specifying an `end` that occurs chronologically before `start` will result in an error.
End *date.Time `json:"end,omitempty"`
}
ResourceChangesRequestParametersInterval specifies the date and time interval for a changes request.
type ResourcePropertyChange ¶
type ResourcePropertyChange struct {
// PropertyName - The property name
PropertyName *string `json:"propertyName,omitempty"`
// BeforeValue - The property value in before snapshot
BeforeValue *string `json:"beforeValue,omitempty"`
// AfterValue - The property value in after snapshot
AfterValue *string `json:"afterValue,omitempty"`
// ChangeCategory - The change category. Possible values include: 'ChangeCategoryUser', 'ChangeCategorySystem'
ChangeCategory ChangeCategory `json:"changeCategory,omitempty"`
// PropertyChangeType - The property change Type. Possible values include: 'PropertyChangeTypeInsert', 'PropertyChangeTypeUpdate', 'PropertyChangeTypeRemove'
PropertyChangeType PropertyChangeType `json:"propertyChangeType,omitempty"`
}
ResourcePropertyChange the resource property change
type ResourceSnapshotData ¶
type ResourceSnapshotData struct {
// SnapshotID - The ID of the snapshot.
SnapshotID *string `json:"snapshotId,omitempty"`
// Timestamp - The time when the snapshot was created.
// The snapshot timestamp provides an approximation as to when a modification to a resource was detected. There can be a difference between the actual modification time and the detection time. This is due to differences in how operations that modify a resource are processed, versus how operation that record resource snapshots are processed.
Timestamp *date.Time `json:"timestamp,omitempty"`
// Content - The resource snapshot content (in resourceChangeDetails response only).
Content interface{} `json:"content,omitempty"`
}
ResourceSnapshotData data on a specific resource snapshot.
type ResourcesHistoryRequest ¶
type ResourcesHistoryRequest struct {
Subscriptions *[]string `json:"subscriptions,omitempty"`
Query *string `json:"query,omitempty"`
Options *ResourcesHistoryRequestOptions `json:"options,omitempty"`
ManagementGroupID *string `json:"managementGroupId,omitempty"`
}
ResourcesHistoryRequest ...
type ResourcesHistoryRequestOptions ¶
type ResourcesHistoryRequestOptions struct {
Interval *DateTimeInterval `json:"interval,omitempty"`
Top *int32 `json:"$top,omitempty"`
Skip *int32 `json:"$skip,omitempty"`
SkipToken *string `json:"$skipToken,omitempty"`
// ResultFormat - Possible values include: 'ResultFormat1Table', 'ResultFormat1ObjectArray'
ResultFormat ResultFormat1 `json:"resultFormat,omitempty"`
}
ResourcesHistoryRequestOptions ...
type ResultFormat ¶
type ResultFormat string
ResultFormat enumerates the values for result format.
const ( // ResultFormatObjectArray ... ResultFormatObjectArray ResultFormat = "objectArray" // ResultFormatTable ... ResultFormatTable ResultFormat = "table" )
func PossibleResultFormatValues ¶
func PossibleResultFormatValues() []ResultFormat
PossibleResultFormatValues returns an array of possible values for the ResultFormat const type.
type ResultFormat1 ¶
type ResultFormat1 string
ResultFormat1 enumerates the values for result format 1.
const ( // ResultFormat1ObjectArray ... ResultFormat1ObjectArray ResultFormat1 = "objectArray" // ResultFormat1Table ... ResultFormat1Table ResultFormat1 = "table" )
func PossibleResultFormat1Values ¶
func PossibleResultFormat1Values() []ResultFormat1
PossibleResultFormat1Values returns an array of possible values for the ResultFormat1 const type.
type ResultTruncated ¶
type ResultTruncated string
ResultTruncated enumerates the values for result truncated.
const ( // ResultTruncatedFalse ... ResultTruncatedFalse ResultTruncated = "false" // ResultTruncatedTrue ... ResultTruncatedTrue ResultTruncated = "true" )
func PossibleResultTruncatedValues ¶
func PossibleResultTruncatedValues() []ResultTruncated
PossibleResultTruncatedValues returns an array of possible values for the ResultTruncated const type.
type ResultType ¶
type ResultType string
ResultType enumerates the values for result type.
const ( // ResultTypeResultTypeFacet ... ResultTypeResultTypeFacet ResultType = "Facet" // ResultTypeResultTypeFacetError ... ResultTypeResultTypeFacetError ResultType = "FacetError" // ResultTypeResultTypeFacetResult ... ResultTypeResultTypeFacetResult ResultType = "FacetResult" )
func PossibleResultTypeValues ¶
func PossibleResultTypeValues() []ResultType
PossibleResultTypeValues returns an array of possible values for the ResultType const type.